==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/9f/9fca315ac1ba38e46d93a222d1771434.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Service/Campaign.php */
class __TwigTemplate_7f53e351b5beb03f6415b374b00e759b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CampaignBundle\\Service;

use Mautic\\CampaignBundle\\Entity\\CampaignRepository;
use Mautic\\EmailBundle\\Entity\\EmailRepository;

/**
 * @deprecated to be removed in 6.0; use CampaignAuditService instead
 */
class Campaign
{
    public function __construct(
        private CampaignRepository \$campaignRepository,
        private EmailRepository \$emailRepository
    ) {
    }

    /**
     * Has campaign at least one unpublished e-mail?
     *
     * @param int \$id
     */
    public function hasUnpublishedEmail(\$id): bool
    {
        \$emailIds = \$this->campaignRepository->fetchEmailIdsById(\$id);

        if (!\$emailIds) {
            return false;
        }

        return \$this->emailRepository->isOneUnpublished(\$emailIds);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Service/Campaign.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Service/Campaign.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Service/Campaign.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/9f/9fca315ac1ba38e46d93a222d1771434.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Service/Campaign.php */
class __TwigTemplate_7f53e351b5beb03f6415b374b00e759b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CampaignBundle\\Service;

use Mautic\\CampaignBundle\\Entity\\CampaignRepository;
use Mautic\\EmailBundle\\Entity\\EmailRepository;

/**
 * @deprecated to be removed in 6.0; use CampaignAuditService instead
 */
class Campaign
{
    public function __construct(
        private CampaignRepository \$campaignRepository,
        private EmailRepository \$emailRepository
    ) {
    }

    /**
     * Has campaign at least one unpublished e-mail?
     *
     * @param int \$id
     */
    public function hasUnpublishedEmail(\$id): bool
    {
        \$emailIds = \$this->campaignRepository->fetchEmailIdsById(\$id);

        if (!\$emailIds) {
            return false;
        }

        return \$this->emailRepository->isOneUnpublished(\$emailIds);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Service/Campaign.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Service/Campaign.php", "/var/www/html/production-demo/app/bundles/CampaignBundle/Service/Campaign.php");
    }
}
